@@ -380,7 +380,7 @@ def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
 
 
 def general_obj_search(request, Obj, ObjForm, search_fields=(), \
-        result_fields=(), template=False):
+        result_fields=(), template=False, *args, **kwargs):
     if not template:
         template = 'generalobj_search.html'
     ret_dic = {}
@@ -389,6 +389,9 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
             ret_dic['datetimefield_exists'], ret_dic['booleanfield_exists']) = \
             get_params_for_search(request, Obj, ObjForm, search_fields, \
             result_fields)
+    if 'passing_scripts' in kwargs:
+        ret_dic['passing_scripts'] = kwargs['passing_scripts']
+    ret_dic['url_new'] = reverse('%s_new' % ret_dic['class_name'].lower())
     return render(request, template, ret_dic)
 
 
